==> tuia-explore-center-api-0.0.1-20190529.120309-28-sources.jar: cn/tuia/explore/center/api/dto/rsp/LikeMessageDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import java.io.Serializable;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: LikeMessageDto.java , v 0.1 2019-05-29 12:34 ElinZhou Exp $
 */
public class LikeMessageDto implements Serializable {
    private static final long serialVersionUID = 4418182271928257916L;

    /**
     * 点赞类型
     * 评论被赞，则使用textContent
     * 帖子被赞，则使用postDto
     *
     * @see cn.tuia.explore.center.api.enums.LikeType
     */
    private int type;

    private String tile;

    private String textContent;

    private PostDto postDto;

    private long firstUserId;

    private long msgId;

    private int count;

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public String getTile() {
        return tile;
    }

    public void setTile(String tile) {
        this.tile = tile;
    }

    public String getTextContent() {
        return textContent;
    }

    public void setTextContent(String textContent) {
        this.textContent = textContent;
    }

    public PostDto getPostDto() {
        return postDto;
    }

    public void setPostDto(PostDto postDto) {
        this.postDto = postDto;
    }

    public long getFirstUserId() {
        return firstUserId;
    }

    public void setFirstUserId(long firstUserId) {
        this.firstUserId = firstUserId;
    }


    public long getMsgId() {
        return msgId;
    }

    public void setMsgId(long msgId) {
        this.msgId = msgId;
    }

    public int getCount() {
        return count;
    }

    public void setCount(int count) {
        this.count = count;
    }
}

==> tuia-explore-center-api-0.0.1-20190530.113355-37-sources.jar: cn/tuia/explore/center/api/dto/rsp/LikeMessageDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: LikeMessageDto.java , v 0.1 2019-05-29 12:34 ElinZhou Exp $
 */
public class LikeMessageDto implements Serializable {
    private static final long serialVersionUID = 4418182271928257916L;

    /**
     * 点赞类型
     * 评论被赞，则使用textContent
     * 帖子被赞，则使用postDto
     *
     * @see cn.tuia.explore.center.api.enums.LikeType
     */
    private int type;

    private String tile;

    private String textContent;

    private PostDto postDto;

    private List<UserDto> userDtoList;

    private long msgId;

    private int count;

    private boolean readed;

    private Date lastTime;

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public String getTile() {
        return tile;
    }

    public void setTile(String tile) {
        this.tile = tile;
    }

    public String getTextContent() {
        return textContent;
    }

    public void setTextContent(String textContent) {
        this.textContent = textContent;
    }

    public PostDto getPostDto() {
        return postDto;
    }

    public void setPostDto(PostDto postDto) {
        this.postDto = postDto;
    }

    public long getMsgId() {
        return msgId;
    }

    public void setMsgId(long msgId) {
        this.msgId = msgId;
    }

    public int getCount() {
        return count;
    }

    public void setCount(int count) {
        this.count = count;
    }

    public List<UserDto> getUserDtoList() {
        return userDtoList;
    }

    public void setUserDtoList(List<UserDto> userDtoList) {
        this.userDtoList = userDtoList;
    }

    public boolean isReaded() {
        return readed;
    }

    public void setReaded(boolean readed) {
        this.readed = readed;
    }

    public Date getLastTime() {
        return lastTime;
    }

    public void setLastTime(Date lastTime) {
        this.lastTime = lastTime;
    }
}
